@@ -18,11 +18,12 @@ class AppInitializer:
 
     def init(self):
         self._make_settings()
-        bean_context = self._create_bean_context()
+        bean_context = WebApplicationContext(self.app)
         self.app.bean_context = bean_context  # register bean context for app
         self._init_app()
         with self.app.app_context():
             self._register_blueprints()
+            bean_context.scan(self.config.settings['project_name'])
             self._refresh_bean_context(bean_context)
 
     def _make_settings(self):
@@ -40,11 +41,6 @@ class AppInitializer:
             s = self.config.settings
             _init_app(self.app, s)
 
-    def _create_bean_context(self) -> WebApplicationContext:
-        bean_context = WebApplicationContext(self.app)
-        bean_context.scan(self.app.name)
-        return bean_context
-
     def _refresh_bean_context(self, bean_context: WebApplicationContext):
         bean_context.refresh()
 
@@ -55,7 +51,7 @@ class AppInitializer:
         registered_blueprints = set()
 
         def iter_blueprints():
-            for module in walk_modules(self.app.name):
+            for module in walk_modules(self.config.settings['project_name']):
                 for obj in vars(module).values():
                     if isinstance(obj, Blueprint) and obj not in registered_blueprints:
                         yield obj
@@ -67,4 +63,4 @@ class AppInitializer:
         del registered_blueprints
 
     def _get_app_module(self):
-        return import_module(self.app.name + '.app')
+        return import_module(self.config.settings['project_name'] + '.app')
