@@ -4,6 +4,7 @@ import os
 import tempfile
 from os.path import join, exists
 import fcntl
+import getpass
 
 from guniflask.config.app_config import settings
 
@@ -21,7 +22,9 @@ class ServiceLock:
         if instance_id in self.locks:
             return True
 
-        temp_dir = join(tempfile.gettempdir(), 'guniflask', self.__class__.__name__)
+        temp_dir = join(tempfile.gettempdir(),
+                        'guniflask.{}'.format(getpass.getuser()),
+                        self.__class__.__name__)
         if not exists(temp_dir):
             os.makedirs(temp_dir, exist_ok=True)
 
